@@ -5,7 +5,7 @@ This module has been written as part of the Cherokee project:
                http://www.cherokee-project.com/
 """
 
-# Copyright (c) 2006-2010, Alvaro Lopez Ortega <alvaro@alobbs.com>
+# Copyright (c) 2006-2011, Alvaro Lopez Ortega <alvaro@alobbs.com>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -43,9 +43,9 @@ import time
 import sys
 import os
 
-__version__   = '1.13'
+__version__   = '1.15'
 __author__    = 'Alvaro Lopez Ortega'
-__copyright__ = 'Copyright 2010, Alvaro Lopez Ortega'
+__copyright__ = 'Copyright 2010-2011, Alvaro Lopez Ortega'
 __license__   = 'BSD'
 
 
@@ -147,11 +147,25 @@ class SCGIHandler (SocketServer.StreamRequestHandler):
             if sys.exc_type != SystemExit:
                 traceback.print_exc()  # Print the error
 
-        try:
-            self.finish()          # Closes wfile and rfile
-            self.request.close()   # ..
+        try: # Closes wfile and rfile
+            self.finish()
         except: pass
 
+        try: # Send a FIN signal
+            self.request.shutdown (socket.SHUT_WR)
+        except: pass
+
+        try: # Wait for the client's ACK+FIN
+            while True:
+                if not self.request.recv(1):
+                    break;
+        except: pass
+
+        try: # Send either ACK, or RST
+            self.request.close()
+        except: pass
+
+
     def handle_request (self):
         self.send('Status: 200 OK\r\n')
         self.send("Content-Type: text/plain\r\n\r\n")
