@@ -3,7 +3,7 @@
 # Concrete5 Wizard
 #
 # Authors:
-#      Taher Shihadeh <taher@unixwars.com>
+#      Taher Shihadeh <taher@octality.com>
 #
 # Copyright (C) 2010 Alvaro Lopez Ortega
 #
@@ -138,7 +138,11 @@ class Commit:
 
         # PHP
         php = CTK.load_module ('php', 'wizards')
+
         error = php.wizard_php_add (next)
+        if error:
+            return {'ret': 'error', 'errors': {'msg': error}}
+
         php_info = php.get_info (next)
 
         # Concrete5
@@ -166,7 +170,11 @@ class Commit:
 
         # PHP
         php = CTK.load_module ('php', 'wizards')
+
         error = php.wizard_php_add (next)
+        if error:
+            return {'ret': 'error', 'errors': {'msg': error}}
+
         php_info = php.get_info (next)
 
         # Concrete5
@@ -248,6 +256,12 @@ class LocalSource:
         return cont.Render().toStr()
 
 
+class PHP:
+    def __call__ (self):
+        php = CTK.load_module ('php', 'wizards')
+        return php.External_FindPHP()
+
+
 class Welcome:
     def __call__ (self):
         cont = CTK.Container()
@@ -291,13 +305,15 @@ VALS = [
 
 # VServer
 CTK.publish ('^/wizard/vserver/concrete5$',   Welcome)
-CTK.publish ('^/wizard/vserver/concrete5/2$', LocalSource)
-CTK.publish ('^/wizard/vserver/concrete5/3$', Host)
+CTK.publish ('^/wizard/vserver/concrete5/2$', PHP)
+CTK.publish ('^/wizard/vserver/concrete5/3$', LocalSource)
+CTK.publish ('^/wizard/vserver/concrete5/4$', Host)
 
 # Rule
 CTK.publish ('^/wizard/vserver/(\d+)/concrete5$',   Welcome)
-CTK.publish ('^/wizard/vserver/(\d+)/concrete5/2$', LocalSource)
-CTK.publish ('^/wizard/vserver/(\d+)/concrete5/3$', WebDirectory)
+CTK.publish ('^/wizard/vserver/(\d+)/concrete5/2$', PHP)
+CTK.publish ('^/wizard/vserver/(\d+)/concrete5/3$', LocalSource)
+CTK.publish ('^/wizard/vserver/(\d+)/concrete5/4$', WebDirectory)
 
 # Common
-CTK.publish (r'^%s$'%(URL_APPLY), Commit, method="POST", validation=VALS)
+CTK.publish (r'^%s'%(URL_APPLY), Commit, method="POST", validation=VALS)
