@@ -293,4 +293,4 @@ CTK.publish ('^/wizard/vserver/(\d+)/django/2$', LocalSource)
 CTK.publish ('^/wizard/vserver/(\d+)/django/3$', WebDirectory)
 
 # Common
-CTK.publish (r'^%s$'%(URL_APPLY), Commit, method="POST", validation=VALS)
+CTK.publish (r'^%s'%(URL_APPLY), Commit, method="POST", validation=VALS)
