@@ -40,7 +40,7 @@ do_parse_file (cherokee_config_node_t *conf, const char *file)
 	cherokee_buffer_t  buf = CHEROKEE_BUF_INIT;
 
 	ret = cherokee_buffer_read_file (&buf, (char *)file);
-	if (ret != ret_ok) return ret;
+	if (ret != ret_ok) goto error;
 
 	ret = cherokee_config_reader_parse_string (conf, &buf);
 	if (ret != ret_ok) goto error;
@@ -84,6 +84,9 @@ do_include (cherokee_config_node_t *conf, cherokee_buffer_t *path)
 			/* Ignore backup files
 			 */
 			entry_len = strlen(entry->d_name);
+			if (unlikely (entry_len <= 0)) {
+				continue;
+			}
 
 			if ((entry->d_name[0] == '.') ||
 			    (entry->d_name[0] == '#') ||
@@ -93,10 +96,13 @@ do_include (cherokee_config_node_t *conf, cherokee_buffer_t *path)
 			}
 
 			ret = cherokee_buffer_add_va (&full_new, "%s/%s", path->buf, entry->d_name);
-			if (unlikely (ret != ret_ok)) return ret;
+			if (unlikely (ret != ret_ok)) {
+				cherokee_buffer_mrproper (&full_new);
+				return ret;
+			}
 
 			ret = do_parse_file (conf, full_new.buf);
-			if (ret != ret_ok) {
+			if (unlikely (ret != ret_ok)) {
 				cherokee_buffer_mrproper (&full_new);
 				return ret;
 			}
