@@ -580,9 +580,13 @@ manage_child_cgi_process (cherokee_handler_cgi_t *cgi, int pipe_cgi[2], int pipe
 	} else {
 		char *file = strrchr (absolute_path, '/');
 
-		*file = '\0';
-		re = chdir (absolute_path);
-		*file = '/';
+		if (file != NULL) {
+			*file = '\0';
+			re = chdir (absolute_path);
+			*file = '/';
+		} else {
+			re = -1;
+		}
 	}
 
 	if (re < 0) {
@@ -625,13 +629,20 @@ manage_child_cgi_process (cherokee_handler_cgi_t *cgi, int pipe_cgi[2], int pipe
 		char buferr[ERROR_MAX_BUFSIZE];
 
 		switch (err) {
+		case ENODEV:
+		case ENOTDIR:
 		case ENOENT:
 			printf ("Status: 404" CRLF_CRLF);
-			break;
+			exit(0);
+		case EPERM:
+		case EACCES:
+		case ENOEXEC:
+			printf ("Status: 403" CRLF_CRLF);
+			exit(0);
 		default:
 			printf ("Status: 500" CRLF_CRLF);
-			printf ("X-Debug: file=%s line=%d cmd=%s: %s" CRLF_CRLF,
-				__FILE__, __LINE__, absolute_path, strerror(err));
+			printf ("X-Debug: file=%s line=%d cmd=%s errno=%d: %s" CRLF_CRLF,
+				__FILE__, __LINE__, absolute_path, err, strerror(err));
 		}
 
 		/* Don't use the logging system (concurrency issues)
@@ -661,8 +672,8 @@ fork_and_execute_cgi_unix (cherokee_handler_cgi_t *cgi)
 
 	/* Creates the pipes ...
 	 */
-	re  = pipe (pipes.cgi);
-	re |= pipe (pipes.server);
+	re  = cherokee_pipe (pipes.cgi);
+	re |= cherokee_pipe (pipes.server);
 
 	if (re != 0) {
 		conn->error_code = http_internal_error;
