@@ -87,22 +87,22 @@ find_empty_port (int starting, int *port)
 	cherokee_buffer_t bind_ = CHEROKEE_BUF_INIT;
 
 	cherokee_buffer_add_str (&bind_, "127.0.0.1");
-
 	cherokee_socket_init (&s);
-	cherokee_socket_set_client (&s, AF_INET);
 
 	while (true) {
+		cherokee_socket_create_fd (&s, AF_INET);
 		ret = cherokee_socket_bind (&s, p, &bind_);
+		cherokee_socket_close (&s);
+
 		if (ret == ret_ok)
 			break;
 
 		p += 1;
-		if (p > 0XFFFF) {
+		if (unlikely (p > 0xFFFF)) {
 			goto error;
 		}
 	}
 
-	cherokee_socket_close (&s);
 	cherokee_socket_mrproper (&s);
 	cherokee_buffer_mrproper (&bind_);
 
