@@ -57,6 +57,11 @@ typedef struct {
 	cherokee_socket_t              socket;
 	cherokee_handler_proxy_poll_t *poll_ref;
 
+	/* Name resolution */
+	const struct addrinfo         *addr_info_ref;
+	cuint_t                        addr_total;
+	cuint_t                        addr_current;
+
 	/* In */
 	cherokee_handler_proxy_enc_t   enc;
 	cherokee_buffer_t              header_in_raw;
@@ -107,11 +112,10 @@ ret_t cherokee_handler_proxy_conn_send         (cherokee_handler_proxy_conn_t  *
 ret_t cherokee_handler_proxy_conn_recv_headers (cherokee_handler_proxy_conn_t  *pconn,
 						cherokee_buffer_t              *body,
 						cherokee_boolean_t              flexible);
-
-/* Utils
- */
-ret_t cherokee_proxy_util_init_socket          (cherokee_socket_t *socket,
-						cherokee_source_t *src);
+ret_t cherokee_handler_proxy_conn_get_addrinfo (cherokee_handler_proxy_conn_t  *pconn,
+						cherokee_source_t              *src);
+ret_t cherokee_handler_proxy_conn_init_socket  (cherokee_handler_proxy_conn_t  *pconn,
+						cherokee_source_t              *src);
 
 #endif /* CHEROKEE_HANDLER_PROXY_HOSTS_H */
 
