@@ -294,8 +294,8 @@ cherokee_validator_digest_response (cherokee_validator_t  *validator,
 				    cherokee_buffer_t     *buf,
 				    cherokee_connection_t *conn)
 {
-	ret_t              ret;
-	cherokee_buffer_t a2 = CHEROKEE_BUF_INIT;
+	ret_t             ret;
+	cherokee_buffer_t a2   = CHEROKEE_BUF_INIT;
 
 	/* A1 has to be in string of length 32:
 	 * MD5_digest(user":"realm":"passwd)
@@ -457,9 +457,11 @@ cherokee_validator_configure (cherokee_config_node_t *conf, void *config_entry)
 
 	/* Sanity checks
 	 */
-	if ((entry->auth_realm == NULL) ||
-	    (cherokee_buffer_is_empty (entry->auth_realm)))
-	{
+	if (entry->auth_realm == NULL) {
+		cherokee_buffer_new (&entry->auth_realm);
+	}
+
+	if (cherokee_buffer_is_empty (entry->auth_realm)) {
 		cherokee_buffer_add_str (entry->auth_realm, REALM_DEFAULT);
 		TRACE (ENTRIES, "No Realm was provided. Setting default realm: %s\n", REALM_DEFAULT);
 	}
