@@ -27,7 +27,7 @@
 
 #include "validator_file.h"
 #include "connection.h"
-
+#include "plugin_loader.h"
 
 typedef struct {
 	cherokee_validator_file_props_t base;
@@ -41,6 +41,7 @@ typedef struct {
 #define PROP_PLAIN(p)     ((cherokee_validator_plain_props_t *)(p))
 #define VAL_PLAIN_PROP(x) (PROP_PLAIN (MODULE(x)->props))
 
+void PLUGIN_INIT_NAME(plain) (cherokee_plugin_loader_t *loader);
 
 ret_t cherokee_validator_plain_new         (cherokee_validator_plain_t **plain, cherokee_module_props_t *props);
 ret_t cherokee_validator_plain_free        (cherokee_validator_plain_t  *plain);
