@@ -6,6 +6,12 @@ vserver!1!rule!180!match!directory = /cgi-bin4
 vserver!1!rule!180!handler = cgi
 """
 
+CGI_BASE = """#!/bin/sh
+echo "Content-Type: text/plain"
+echo
+echo "PathInfo is $PATH_INFO"
+"""
+
 class Test (TestBase):
     def __init__ (self):
         TestBase.__init__ (self, __file__)
@@ -18,10 +24,4 @@ class Test (TestBase):
 
     def Prepare (self, www):
         self.Mkdir (www, "cgi-bin4/inside")
-        self.WriteFile (www, "cgi-bin4/inside/test", 0755,
-                        """#!/bin/sh
-
-                        echo "Content-Type: text/plain"
-                        echo
-                        echo "PathInfo is $PATH_INFO"
-                        """)
+        self.WriteFile (www, "cgi-bin4/inside/test", 0755, CGI_BASE)
