@@ -12,7 +12,7 @@ vserver!1!rule!390!auth!passwdfile = %s
 
 class Test (TestBase):
     def __init__ (self):
-        TestBase.__init__ (self)
+        TestBase.__init__ (self, __file__)
         self.name             = "Auth basic"
         self.request          = "GET /auth1/ HTTP/1.0\r\n"
         self.expected_error   = 401
