@@ -4,7 +4,7 @@ MAGIC = "Cherokee accepts dot dot inside the request, even with dot slash"
 
 class Test (TestBase):
     def __init__ (self):
-        TestBase.__init__ (self)
+        TestBase.__init__ (self, __file__)
         self.name = "Dot dot reduction II"
         self.request           = "GET /./dotdot3/./aa/bb/cc/../../dd/././../../dir/././file HTTP/1.0\r\n"
         self.expected_error    = 200
