@@ -22,9 +22,12 @@ class Test (TestBase):
 
         self.request           = "GET /%s/Range100b2 HTTP/1.0\r\n" % (DIR) +\
                                  "Range: bytes=-%d\r\n" % (OFFSET)
-        self.expected_error    = 206
-        self.expected_content  = [MAGIC[:OFFSET], "Content-Length: %d" % (OFFSET)]
+
         self.forbidden_content = MAGIC[OFFSET:]
+        self.expected_error    = 206
+        self.expected_content  = [MAGIC[-OFFSET:],
+                                  "Content-Length: %d" % (OFFSET),
+                                  "Content-Range: bytes %d-%d/%d" % (LENGTH-OFFSET, LENGTH-1, LENGTH)]
 
     def Prepare (self, www):
         test_dir = self.Mkdir (www, DIR)
