@@ -6,18 +6,7 @@ from util import *
 # This QA test checks:
 # http://bugs.cherokee-project.com/504
 
-# NOTE: On PHP error management
-#
-# PHP could complain while executing this script because there isn't a
-# 'var' variable. Depending of the interpreter and configuration this
-# could be a problem. Please ensure that the 'log_errors' entry of
-# your php.ini configuration file is set to 'Off'. Otherwise, it may
-# print trash to stdout and mess up the FastCGI data stream. Remember:
-#
-#   log_errors = Off
-#
-
-
+POST_VAR    = "var"
 POST_LENGTH = 1024 * 10
 POST_EXTRA  = "\r\n\r\n"
 FILENAME    = "post_4extra.php"
@@ -29,12 +18,16 @@ class Test (TestBase):
 
         self.request          = "POST /%s HTTP/1.1\r\n" %(FILENAME) +\
                                 "Host: localhost\r\n" +\
+                                "Content-Type: application/x-www-form-urlencoded\r\n" +\
                                 "Content-length: %d\r\n" % (POST_LENGTH)
         self.expected_error   = 200
-        self.post             = letters_random (POST_LENGTH) + POST_EXTRA
+        self.post             = POST_VAR + "=" +\
+                                letters_random (POST_LENGTH-len(POST_VAR)-1) +\
+                                POST_EXTRA
 
     def Prepare (self, www):
-        self.WriteFile (www, FILENAME, 0444, "<?php echo $_POST['var']; ?>")
+        self.WriteFile (www, FILENAME, 0444,
+                        "<?php echo $_POST['%s']; ?>" %(POST_VAR))
 
     def Precondition (self):
         return os.path.exists (look_for_php())
